@@ -7,7 +7,7 @@
  * Perl5 language module for SWIG.
  * ------------------------------------------------------------------------- */
 
-char cvsroot_perl5_cxx[] = "$Id: perl5.cxx 10003 2007-10-17 21:42:11Z wsfulton $";
+char cvsroot_perl5_cxx[] = "$Id: perl5.cxx 10270 2008-02-27 15:29:55Z wsfulton $";
 
 #include "swigmod.h"
 #include "cparse.h"
@@ -304,6 +304,7 @@ public:
     /* Start creating magic code */
 
     Printv(magic,
+           "#ifdef __cplusplus\nextern \"C\" {\n#endif\n\n",
 	   "#ifdef PERL_OBJECT\n",
 	   "#define MAGIC_CLASS _wrap_", module, "_var::\n",
 	   "class _wrap_", module, "_var : public CPerlObj {\n",
@@ -324,6 +325,7 @@ public:
     /* Dump out variable wrappers */
 
     Printv(magic, "\n\n#ifdef PERL_OBJECT\n", "};\n", "#endif\n", NIL);
+    Printv(magic, "\n#ifdef __cplusplus\n}\n#endif\n", NIL);
 
     Printf(f_header, "%s\n", magic);
 
@@ -780,6 +782,7 @@ public:
     /* Create a Perl function for setting the variable value */
 
     if (!GetFlag(n, "feature:immutable")) {
+      Setattr(n, "wrap:name", set_name);
       Printf(setf->def, "SWIGCLASS_STATIC int %s(pTHX_ SV* sv, MAGIC * SWIGUNUSEDPARM(mg)) {\n", set_name);
       Printv(setf->code, tab4, "MAGIC_PPERL\n", NIL);
 
@@ -802,6 +805,7 @@ public:
     }
 
     /* Now write a function to evaluate the variable */
+    Setattr(n, "wrap:name", get_name);
     int addfail = 0;
     Printf(getf->def, "SWIGCLASS_STATIC int %s(pTHX_ SV *sv, MAGIC *SWIGUNUSEDPARM(mg)) {\n", get_name);
     Printv(getf->code, tab4, "MAGIC_PPERL\n", NIL);
